@@ -60,21 +60,21 @@ class HeaderToLabelMiddleware(object):
 
         log_entry_info = dict(
             type=self._REQUEST,
-            nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
             method=request.method,
             url=request.build_absolute_uri()
         )
+        log_entry_info.update(nim_headers)
 
         log_entry_debug = dict(
             type=self._REQUEST,
-            nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=self.__get_time_in_milliseconds(),
             method=request.method,
             body=Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE)),
             url=request.build_absolute_uri()
         )
+        log_entry_debug.update(nim_headers)
 
         for label, header_name in log_label_request_settings.items():
             header_value = self._get_header(request, header_name)
@@ -90,7 +90,6 @@ class HeaderToLabelMiddleware(object):
         nim_headers = Utils.get_raw_nim_headers(request)
         log_entry = dict(
             type=self._RESPONSE,
-            nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=self.__get_time_in_milliseconds(),
             method=request.method,
@@ -101,16 +100,17 @@ class HeaderToLabelMiddleware(object):
                                                 settings.MAX_REQUEST_RESPONSE_SIZE) if response.status_code < 400 else response.content,
             url=request.build_absolute_uri()
         )
+        log_entry.update(nim_headers)
 
         log_entry_info = dict(
             type=self._RESPONSE,
-            nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=self.__get_time_in_milliseconds(),
             status_code=response.status_code,
             method=request.method,
             url=request.build_absolute_uri()
         )
+        log_entry_info.update(log_entry_info)
 
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
         for label in log_label_request_settings:
@@ -135,7 +135,6 @@ class HeaderToLabelMiddleware(object):
         nim_headers = Utils.get_raw_nim_headers(request)
         log_entry = dict(
             type=self._ERROR,
-            nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=self.__get_time_in_milliseconds(),
             method=request.method,
@@ -145,16 +144,17 @@ class HeaderToLabelMiddleware(object):
             url=request.build_absolute_uri(),
             stack_trace=traceback.format_exc()
         )
+        log_entry.update(nim_headers)
 
         log_entry_info = dict(
             type=self._ERROR,
-            nim_headers=nim_headers,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=self.__get_time_in_milliseconds(),
             status_code="500",
             method=request.method,
             url=request.build_absolute_uri()
         )
+        log_entry_info.update(nim_headers)
 
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
         for label in log_label_request_settings:
