@@ -7,13 +7,23 @@ class Utils:
         NIM_HEADER_REG_EXP = r"^HTTP\_NIM\_"
         HTTP_REG_EXP = r"^HTTP\_"
         nim_headers = {}
-        for key,value in request.META.items():
+        for key, value in request.META.items():
             if re.match(NIM_HEADER_REG_EXP, key):
                 transformed_key = re.sub(HTTP_REG_EXP, "", key).replace("_", "-")
                 nim_headers[transformed_key] = value
 
         return nim_headers
 
+    @classmethod
+    def get_raw_nim_headers(cls, request):
+        NIM_HEADER_REG_EXP = r"^HTTP\_NIM\_"
+        nim_headers = {}
+        for key, value in request.META.items():
+            if re.match(NIM_HEADER_REG_EXP, key):
+                nim_headers[key] = value
+
+        return nim_headers
+
     @classmethod
     def adjust_string_length(cls, value, max_length):
         TRUNCATE_INDICATOR = "---[TRUNCATED]---"
